@@ -13,8 +13,6 @@ import logging
 import os
 import re
 
-from six import iteritems
-
 import splunk_appinspect
 from splunk_appinspect.configuration_file import ConfigurationFile, ConfigurationSection
 from splunk_appinspect.splunk_pretrained_sourcetypes_list import (
@@ -122,7 +120,7 @@ def check_props_conf_has_report_option_and_transforms_conf_exist(app, reporter):
 
     config_file_paths = app.get_config_file_paths("props.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             props_config = app.props_conf(directory)
             sections_with_transforms = list(
@@ -166,7 +164,7 @@ def check_props_conf_has_report_option_and_transforms_conf_has_matching_stanza(
 
     config_file_paths = app.get_config_file_paths("props.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             props_config = app.props_conf(directory)
             props_sections_with_transforms = list(
@@ -223,7 +221,7 @@ def check_props_conf_has_report_option_and_transforms_conf_has_required_option(
 
     config_file_paths = app.get_config_file_paths("props.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             props_config: ConfigurationFile = app.props_conf(directory)
             props_sections_with_transforms = list(
@@ -346,7 +344,7 @@ def check_props_conf_regex_stanza_name_followed_by_double_colon(app, reporter):
     """
     config_file_paths = app.get_config_file_paths("props.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             props_conf = app.props_conf(directory)
 
@@ -478,7 +476,7 @@ def check_props_conf_extract_option_has_named_capturing_group(app, reporter):
 
     config_file_paths = app.get_config_file_paths("props.conf")
     if config_file_paths:
-        for directory, filename in iteritems(config_file_paths):
+        for directory, filename in iter(config_file_paths.items()):
             file_path = os.path.join(directory, filename)
             props_config: ConfigurationFile = app.props_conf(directory)
             props_extract_sections = list(
